Type Definition shuttle_tower::ShuttleTower
source · pub type ShuttleTower<T> = Result<TowerService<T>, Error>;Expand description
The return type that should be returned from the [shuttle_runtime::main] function.
pub type ShuttleTower<T> = Result<TowerService<T>, Error>;The return type that should be returned from the [shuttle_runtime::main] function.